@@ -140,19 +140,12 @@ def _run_shell_command(cmd, throw_on_error=False):
 
 
 def _get_git_directory():
-    parent_dir = os.path.dirname(os.curdir)
-    while True:
-        git_dir = os.path.join(parent_dir, '.git')
-        if os.path.exists(git_dir):
-            return git_dir
-        parent_dir, child = os.path.split(parent_dir)
-        if not child:   # reached to root dir
-            return None
+    return _run_shell_command("git rev-parse --git-dir", None)
 
 
 def get_boolean_option(option_dict, option_name, env_name):
     return ((option_name in option_dict
-             and option_dict[option_name].lower() in TRUE_VALUES) or
+             and option_dict[option_name][1].lower() in TRUE_VALUES) or
             str(os.getenv(env_name)).lower() in TRUE_VALUES)
 
 
@@ -212,9 +205,10 @@ _rst_template = """%(heading)s
 %(underline)s
 
 .. automodule:: %(module)s
-  :members:
-  :undoc-members:
-  :show-inheritance:
+
+:members:
+:undoc-members:
+:show-inheritance:
 """
 
 
@@ -315,7 +309,7 @@ try:
 
             try:
                 app.build(force_all=self.all_files)
-            except Exception, err:
+            except Exception as err:
                 from docutils import utils
                 if isinstance(err, utils.SystemMessage):
                     sys.stder.write('reST markup error:\n')
@@ -334,7 +328,7 @@ try:
             option_dict = self.distribution.get_option_dict('pbr')
             if ('autodoc_index_modules' in option_dict and
                     option_dict.get(
-                        'autodoc_index_modules').lower() in TRUE_VALUES and
+                        'autodoc_index_modules')[1].lower() in TRUE_VALUES and
                     not os.getenv('SPHINX_DEBUG')):
                 self.generate_autoindex()
 
