@@ -16,6 +16,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from __future__ import print_function
+
 import os
 import StringIO
 import sys
@@ -61,7 +63,7 @@ class MailmapTestCase(tests.BaseTestCase):
         self.mailmap = os.path.join(self.git_dir, '.mailmap')
 
     def test_mailmap_with_fullname(self):
-        print self.mailmap, self.git_dir
+        print(self.mailmap, self.git_dir)
         with open(self.mailmap, 'w') as mm_fh:
             mm_fh.write("Foo Bar <email@foo.com> Foo Bar <email@bar.com>\n")
         self.assertEqual({'<email@bar.com>': '<email@foo.com>'},
@@ -125,7 +127,8 @@ class SkipFileWrites(tests.BaseTestCase):
         self.filename = os.path.join(self.temp_path, self.filename)
         self.option_dict = dict()
         if self.option_key is not None:
-            self.option_dict[self.option_key] = self.option_value
+            self.option_dict[self.option_key] = ('setup.cfg',
+                                                 self.option_value)
         self.useFixture(
             fixtures.EnvironmentVariable(self.env_key, self.env_value))
 
@@ -247,7 +250,7 @@ class BuildSphinxTest(tests.BaseTestCase):
     def test_build_doc(self):
         if self.has_opt:
             self.distr.command_options["pbr"] = {
-                "autodoc_index_modules": self.autodoc}
+                "autodoc_index_modules": ('setup.cfg', self.autodoc)}
         build_doc = packaging.LocalBuildDoc(self.distr)
         build_doc.run()
 
